pub fn process_pumpswap_swap_instruction(
instruction: &Instruction<'_>,
swap_event_instruction: &Instruction<'_>,
direction: SwapDirection,
block_time: u64,
slot: u64,
index: u64,
atomic_instruction_index: u8,
signers: &HashSet<Pubkey>,
signature: &Signature,
) -> SwapTxExpand description
Process a Pumpswap swap instruction and create a SwapTx. Assumes the instruction has been validated as a valid Pumpswap swap. Needs the event instruction that follows the swap instruction to extract swap details.